import 'package:clean_android_design/clean_android_design.dart';
import 'package:flutter/material.dart';

import 'navigator_widget.dart';

class MenuWidget extends StatefulWidget {
  final List<String> tabTitles;
  final List<IconData> tabIcons;

  final Widget Function(BuildContext context, int pageIndex) pageBuilder;

  const MenuWidget({
    Key key,
    this.tabTitles,
    this.tabIcons,
    this.pageBuilder,
  }) : super(key: key);

  @override
  _MenuWidgetState createState() => _MenuWidgetState();
}

class _MenuWidgetState extends State<MenuWidget> {
  bool hover = false;
  int selectedTapPageIndex = 0;

  @override
  void initState() {
    super.initState();
    Future.delayed(Duration(milliseconds: 0), () => _clickMenuItem(0));
  }

  @override
  Widget build(BuildContext context) {
    return MouseRegion(
      onExit: (event) => setState(() => hover = false),
      onEnter: (event) => setState(() => hover = true),
      child: AnimatedContainer(
        duration: Duration(milliseconds: 40),
        width: hover ? 200 : 50,
        color: CleanAndroidDesignDefaultColors.defaultColor,
        child: Stack(
          children: <Widget>[
            Column(
              children: <Widget>[
                AnimatedContainer(
                  duration: Duration(milliseconds: 40),
                  padding: EdgeInsets.symmetric(
                      vertical: 5.0, horizontal: hover ? 35.0 : 5.0),
                  child: Row(
                    children: <Widget>[
                      Container(
                        width: 40,
                        height: 40,
                        decoration: BoxDecoration(
                          color: CleanAndroidDesignDefaultColors.accentLight,
                          borderRadius: BorderRadius.circular(15),
                        ),
                        child: Center(
                          child: Text(
                            "WT",
                            style: TextStyle(
                                color: Colors.grey[200],
                                decoration: TextDecoration.none,
                                fontWeight: FontWeight.w500,
                                fontSize: 22),
                          ),
                        ),
                      ),
                      Container(width: 5),
                      Text(
                        "Admin",
                        style: TextStyles.textStyleSize(22).copyWith(
                          color:
                              CleanAndroidDesignDefaultColors.defaultColorLight,
                          fontWeight: FontWeight.w500,
                        ),
                      )
                    ],
                  ),
                ),
              ]..addAll(widget.tabTitles
                  .asMap()
                  .map((index, title) => MapEntry(
                      index,
                      Padding(
                        padding: const EdgeInsets.only(top: 8),
                        child:
                            _getMenuItem(widget.tabIcons[index], title, index),
                      )))
                  .values
                  .toList()),
            ),
          ],
        ),
      ),
    );
  }

  Widget _getMenuItem(IconData icon, String title, int index) {
    return Container(
      width: 200,
      child: Material(
        type: MaterialType.transparency,
        child: InkWell(
          hoverColor: Color.fromRGBO(80, 80, 80, 1),
          highlightColor: Color.fromRGBO(80, 80, 80, 1),
          onTap: () {
            if (index == selectedTapPageIndex) return;
            setState(() {
              selectedTapPageIndex = index;
            });
            _clickMenuItem(index);
          },
          child: Padding(
            padding: const EdgeInsets.symmetric(horizontal: 14, vertical: 7),
            child: Row(
              children: <Widget>[
                Icon(
                  icon,
                  color: CleanAndroidDesignDefaultColors.defaultColorLight,
                  size: 23,
                ),
                Container(width: 14),
                Text(
                  title,
                  style: TextStyles.textStyleSize(16).copyWith(
                    color: CleanAndroidDesignDefaultColors.defaultColorLight,
                  ),
                )
              ],
            ),
          ),
        ),
      ),
    );
  }

  void _clickMenuItem(int index) {
    SplitNavigator.of(SplitNavigatorSide.left)
        .pushReplacement(MaterialPageRoute(
      builder: (context) => widget.pageBuilder(context, selectedTapPageIndex),
    ));
    SplitNavigator.of(SplitNavigatorSide.right)
        .popUntil((route) => route is NoPageRoute);
  }
}
